pub struct GenesisCore { /* private fields */ }Expand description
Genesis acts as the embedded core of the interchangeable part architecture.
Implementations
Sourceimpl GenesisCore
impl GenesisCore
Sourcepub fn new() -> Result<Self, GraphError>
pub fn new() -> Result<Self, GraphError>
Create a new instance of the Genesis core.
Sourcepub fn graph(&self) -> &DeterministicGraph
pub fn graph(&self) -> &DeterministicGraph
Access the underlying deterministic graph.
Sourcepub fn execute_transaction(
&self,
delta: &RdfDelta,
) -> Result<GraphReceipt, GraphError>
pub fn execute_transaction( &self, delta: &RdfDelta, ) -> Result<GraphReceipt, GraphError>
Execute a transaction with the core using an RdfDelta.